
Skill Metrics
=============

The code in this directory is taken from
https://github.com/PeterRochford/SkillMetrics and falls under the GPL 3.0
License in the LICENSE.txt file.

I adopted the code because I relied upon it for a couple features, but the
SkillMetrics install via 'pip' is broken because the dependencies are not
accounted for.
